Page 8 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 8

Home

    Ancient Babylon

    Is not this great Babylon, that I have built for the
    house of the kingdom by the might of my power, and for
    the honour of my majesty?

    Woot taan

    an idle one; for Babylon was not only one of the most
    beautiful cities | in _the world, it was also the most

    powerful. Nebuchadnezzar (606-561 B.C. ) had led it to
    the zenith of its power.

    the cradle of the human race (the Euphrates-Tigris
    Valley, now part of Iraq), Babylon's history starts even
    before 2400 B.C. and goes back to the Tower of Babel.
    It was important enough to be mentioned in the Old
    Testament more than 250 times.

    Before the discovery of the Behistun Rock in 1835 by
    Britain's Sir Henry Rawlinson, very little was known
    about Ancient Babylon outside of Old Testament
    history. On the face of this huge rock, 400 feet above a
    road, was found an inscription engraved in 516 B.C. by
    order of Darius, King of Persia, (521-485 B.C.). This
    was the same Darius who helped to rebuild the Temple
    at Jerusalem as recorded in the Book of Ezra.

    Chapter 1

    Daniel 4:30

    This boast of Nebuchadnezzar in Daniel 4:30 was not

    Located in an area many Bible scholars consider to be